@@ -2,16 +2,23 @@ package HTML::Tree;
 
 =head1 NAME
 
-HTML::Tree - overview of HTML::TreeBuilder et al
+HTML::Tree - build and scan parse-trees of HTML
 
 =head1 VERSION
 
-Version 3.19_04
+3.23_1
 
 =cut
 
+# HTML::Tree is basically just a happy alias to HTML::TreeBuilder.
+
+use warnings;
+use strict;
+
+use HTML::TreeBuilder ();
+
 use vars qw( $VERSION );
-$VERSION = '3.19_04';
+$VERSION = '3.23_1';
 
 =head1 SYNOPSIS
 
@@ -30,20 +37,22 @@ $VERSION = '3.19_04';
 
 =cut
 
-# HTML::Tree is basically just a happy alias to HTML::TreeBuilder.
-use HTML::TreeBuilder ();
-
 sub new {
-  shift; unshift @_, 'HTML::TreeBuilder';
-  goto &HTML::TreeBuilder::new;
+    shift;
+    unshift @_, 'HTML::TreeBuilder';
+    goto &HTML::TreeBuilder::new;
 }
+
 sub new_from_file {
-  shift; unshift @_, 'HTML::TreeBuilder';
-  goto &HTML::TreeBuilder::new_from_file;
+    shift;
+    unshift @_, 'HTML::TreeBuilder';
+    goto &HTML::TreeBuilder::new_from_file;
 }
+
 sub new_from_content {
-  shift; unshift @_, 'HTML::TreeBuilder';
-  goto &HTML::TreeBuilder::new_from_content;
+    shift;
+    unshift @_, 'HTML::TreeBuilder';
+    goto &HTML::TreeBuilder::new_from_content;
 }
 
 =head1 DESCRIPTION
@@ -87,6 +96,24 @@ data structures should read just the last article.  Readers without
 that background should read the first, then the second, and then the
 third.
 
+=head2 new
+
+Redirects to HTML::TreeBuilder::new
+
+=cut
+
+=head2 new_from_file
+
+Redirects to HTML::TreeBuilder::new_from_file
+
+=cut
+
+=head2 new_from_content
+
+Redirects to HTML::TreeBuilder::new_from_content
+
+=cut
+
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -144,23 +171,27 @@ Any patches sent should be diffed against this repository.
 
 =head1 ACKNOWLEDGEMENTS
 
-Thanks to Gisle Aas and Sean Burke for their original work.
+Thanks to Gisle Aas, Sean Burke and Andy Lester for their original work.
+
 Thanks to Chicago Perl Mongers (http://chicago.pm.org) for their
 patches submitted to HTML::Tree as part of the Phalanx project
-(http://qa.perl.org/phalanx).  Thanks to Terrence Brannon for additional
-patches.
+(http://qa.perl.org/phalanx).
+
+Thanks to the following people for additional patches and documentation:
+Terrence Brannon, Gordon Lack, Chris Madsen and Ricardo Signes.
 
 =head1 AUTHOR
 
 Original HTML-Tree author Gisle Aas.  Handed off to Sean M. Burke.
-Currently maintained by Andy Lester C<< <andy at petdance.com> >>.
+and Andy Lester.  Currently maintained by Pete Krawczyk
+C<< <petek@cpan.org> >>.
 
 =head1 COPYRIGHT
 
-Copyright 1995-1998 Gisle Aas; copyright 1999-2002 Sean M. Burke.
-(Except the articles contained in HTML::Tree::AboutObjects,
-HTML::Tree::AboutTrees, and HTML::Tree::Scanning, which are all
-copyright 2000 The Perl Journal.)
+Copyright 1995-1998 Gisle Aas; 1999-2004 Sean M. Burke; 
+2005 Andy Lester; 2006 Pete Krawczyk.  (Except the articles
+contained in HTML::Tree::AboutObjects, HTML::Tree::AboutTrees, and
+HTML::Tree::Scanning, which are all copyright 2000 The Perl Journal.)
 
 Except for those three TPJ articles, the whole HTML-Tree distribution,
 of which this file is a part, is free software; you can redistribute
@@ -169,10 +200,9 @@ it and/or modify it under the same terms as Perl itself.
 Those three TPJ articles may be distributed under the same terms as
 Perl itself.
 
-The programs and documentation in this dist are distributed in
-the hope that they will be useful, but without any warranty; without
-even the implied warranty of merchantability or fitness for a
-particular purpose.
+The programs in this library are distributed in the hope that they
+will be useful, but without any warranty; without even the implied
+warranty of merchantability or fitness for a particular purpose.
 
 =cut
 
